@@ -301,7 +301,7 @@ class Client:
 
     def add_collection_from_path(self, path: str) -> List[Dict]:
         """
-        Will take take a path such as '/photos/arts/paintings/'
+        Will take a path such as '/photos/arts/paintings/'
         and build the corresponding hierarchy of collections. The hierarchy
         is returned as a list of serialized collections.
 
@@ -871,6 +871,24 @@ class Client:
         """
         return self.__call("rename_resource", [resource_id, title])
 
+    def replace_file(self, from_resource_id: int, to_resource_id: int) -> bool:
+        """
+        Replace a file by another using two existing resources.
+
+        The two resources are expected to be of File type. Then the
+        following operations are performed:
+
+        - metas from the "ExifTool" set are removed from the destination resource instance
+        - metas from the "ExifTool" set are transfered from the source resource instance to the destination resource instance
+        - the destination resource instance gets the file hash from the source resource instance
+        - the source resource instance is deleted
+        - the destination resource instance is saved
+
+        Such that all title/metas/tags/collections of the destination resource instance are untouched,
+        excluding exif metas that are transfered from the source.
+        """
+        return self.__call("replace_file", [from_resource_id, to_resource_id])
+
     def resource(self, resource_id: int) -> Optional[Dict]:
         """
         Get a resource given its id.
@@ -929,6 +947,13 @@ class Client:
             "resources", [collection_id, include_metas, limit_from, limit_to]
         )
 
+    def set_is_oai_record(self, collection_id: int, is_oai_record: bool = True) -> bool:
+        """
+        Set/unset the collection as a OAI-PMH record. The creation date
+        will be used in OAI-PMH requests.
+        """
+        return self.__call("set_is_oai_record", [collection_id, is_oai_record])
+
     def set_representative_resource(
         self, collection_id: int, resource_id: int = None
     ) -> bool:
